# base-in-back-end
服务端基础框架

# 目录结构
```
_screenshot                             截图指南
nginx           
sql                                     项目提供的基础数据库脚本文件
src                                     Maven目录结构（代码）
    -|  main
        -|  java
            -|  com.tocean.app          包目录
                -|  aspect              AOP切面
                -|  config              项目配置（等同于SSM的各种*.xml文件）
                -|  constant            静态变量
                -|  controller          提供对外的接口类
                -|  dto                 公共的类传输对象
                -|  entity              实体（与数据库表对应）
                -|  mapper              Mybatis相关的类
                -|  service             业务方法
                -|  util                工具类
                -|  Application         启动类
                -|  ApplicationRunner   启动类钩子
    -|  test                            单元测试类
pom.xml                                 Maven项目依赖描述文件
README.md                               项目说明
```

# 知识准备
- SpringBoot
  - https://www.bilibili.com/video/BV1ti4y1G7yX
- Mybatis-Plus
  - https://www.imooc.com/learn/1130
  - https://www.imooc.com/learn/1171
- Lombok
  - https://www.bilibili.com/video/BV1PJ411j7fS
  - https://www.bilibili.com/video/BV1YC4y1h76L
- Swagger
  - https://www.bilibili.com/video/BV184411J7Vy
  - https://www.bilibili.com/video/BV1Y441197Lw

# 如何启动
## 创建数据库（MySQL）
![](/_screenshot/WX20200831-214813.png)
![](/_screenshot/WX20200831-215217.png)

## 修改数据库链接信息
- /base-in-back-end/src/main/resources/application-dev.yaml
更改所连接的数据库账号密码
```
spring:
  datasource:
    url: jdbc:mysql://127.0.0.1:3306/base-in-back-end?serverTimezone=Asia/Shanghai&useUnicode=true&characterEncoding=UTF-8&useSSL=false
    username: root
    password: 123456
```

## 运行Application
![](/_screenshot/WX20200831-223210.png)
![](/_screenshot/WX20200831-223703.png)

## Swagger接口文档
![](/_screenshot/WX20200831-224002.png)
http://127.0.0.1:8080/base-in-back-end/swagger-ui.html

## 启动应用（Linux服务器启动命令）
```
netstat -nplt
kill xxx
nohup java -jar ./base-in-back-end-0.0.1-SNAPSHOT.jar --server.port=9090 --spring.profiles.active=prod >nohup.out&
tail -f -n 200 nohup.out
```
