package com.tocean.app.config;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.SpringBootConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.http.converter.json.MappingJackson2HttpMessageConverter;
import org.springframework.web.accept.ContentNegotiationManager;
import org.springframework.web.servlet.config.annotation.*;
import org.springframework.web.servlet.mvc.method.annotation.RequestMappingHandlerAdapter;

import java.util.Collections;

/**
 * 功能描述：
 */
@EnableWebMvc
@ComponentScan(basePackages = "com.tocean.app")
@SpringBootConfiguration
public class WebMvcConfig implements WebMvcConfigurer {

    @Value("${file.path}")
    private String filePath;

    @Bean
    public RequestMappingHandlerAdapter requestMappingHandlerAdapter(@Autowired MappingJackson2HttpMessageConverter mappingJackson2HttpMessageConverter, @Autowired ContentNegotiationManager mvcContentNegotiationManager) {
        RequestMappingHandlerAdapter requestMappingHandlerAdapter = new RequestMappingHandlerAdapter();
        requestMappingHandlerAdapter.setMessageConverters(Collections.singletonList(mappingJackson2HttpMessageConverter));
        requestMappingHandlerAdapter.setContentNegotiationManager(mvcContentNegotiationManager);
        return requestMappingHandlerAdapter;
    }

    @Bean
    public MappingJackson2HttpMessageConverter mappingJackson2HttpMessageConverter() {
        return new MappingJackson2HttpMessageConverter();
    }

    @Override
    public void addViewControllers(ViewControllerRegistry registry) {
    }

    @Override
    public void addResourceHandlers(ResourceHandlerRegistry registry) {
        /* 和页面有关的静态目录都放在项目的static目录下 */
        registry.addResourceHandler("/static/**").addResourceLocations("classpath:/static/");

        /* 自定义上传映射路径 */
        registry.addResourceHandler("/file/**").addResourceLocations("file:" + filePath + "/");
    }

    /**
     * 功能描述：
     * 结合Security之后，还需要在SecurityConfig中设置`and().cors().and().csrf().disable()`
     *
     * @param registry
     */
    @Override
    public void addCorsMappings(CorsRegistry registry) {
        registry.addMapping("/**") // 设置允许跨域的路径
                .allowCredentials(true) // 师傅允许证书，不再默认开启
                .allowedOrigins("*") // 设置允许跨域请求的域名
                .allowedHeaders("*")
                .allowedMethods("*")
                .maxAge(60 * 60); // 跨域允许时间
    }

}
