package com.tocean.app.controller.admin;

import com.tocean.app.controller.request.LevelTimuOperateRequest;
import com.tocean.app.controller.request.LevelTimuRequest;
import com.tocean.app.dto.request.BaseRequest;
import com.tocean.app.dto.response.BasePageResponse;
import com.tocean.app.dto.response.BaseResponse;
import com.tocean.app.entity.Level;
import com.tocean.app.entity.LevelTimu;
import com.tocean.app.service.LevelTimuService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Api(description = "题目")
@Slf4j
@CrossOrigin
@RestController("LevelTimuController")
@RequestMapping("/admin/levelTimu")
public class LevelTimuController {

    @Autowired
    private LevelTimuService levelTimuService;

    @ApiOperation(value = "查询题目")
    @PostMapping("/detail")
    public BaseResponse<BasePageResponse<LevelTimu>> page(@Valid @RequestBody BaseRequest<LevelTimuRequest> request) {
        levelTimuService.getTimu(request.getData().getLevel_id());
        return BaseResponse.success();
    }

    /**
     * 新增
     */
    @PostMapping("/add")
    public BaseResponse<Integer> addTiMu(@RequestBody LevelTimu levelTimu)
    {
        return BaseResponse.success(levelTimuService.addTiMu(levelTimu));
    }

    @GetMapping("/{id}")
    public BaseResponse<LevelTimu> getTmInfo(@PathVariable("id") String id){
        return BaseResponse.success(levelTimuService.getTmInfo(id));
    }

    /**
     * 修改
     */
    @PutMapping
    public BaseResponse<Integer> updateTiMu(@RequestBody LevelTimu levelTimu)
    {

        return BaseResponse.success(levelTimuService.updateTiMu(levelTimu));
    }

    /**
     * 删除
     */
    @DeleteMapping("/{timuId}")
    public BaseResponse<Integer> removeTiMu(@PathVariable String timuId)
    {
        return BaseResponse.success(levelTimuService.removeTiMu(timuId));
    }

    @ApiOperation(value = "查询关卡关联的题目")
    @GetMapping("/{levelId}/link")
    public BaseResponse<List<LevelTimu>> page(@PathVariable("levelId") String levelId) {
        return BaseResponse.success(levelTimuService.link(levelId));
    }
    //todo 关联接口
    @ApiOperation(value = "关联接口")
    @PostMapping
    public BaseResponse<?> Related(@RequestBody BaseRequest<LevelTimuOperateRequest> operateDto) {
        System.out.println(operateDto);
        levelTimuService.Related(operateDto.getData().getLevelId(), operateDto.getData().getTimuId());
        return BaseResponse.success();
    }
    //todo 取消关联接口
    @ApiOperation(value = "取消关联")
    @PostMapping("/association/delete")
    public BaseResponse<?>  delete(@RequestBody  BaseRequest<LevelTimuOperateRequest> operateDto) {
        System.out.println(operateDto);
        levelTimuService.delete(operateDto.getData().getLevelId(),operateDto.getData().getTimuId());
        return BaseResponse.success();
    }
}
